@@ -27,49 +27,30 @@
 #include "Rk.h"
 #include "RkLog.h"
 
-#ifdef RK_OS_WIN
-#define WINVER 0x0501
-#include <windows.h>
-
-struct RK_EXPORT RkWindowId {
-    RkWindowId(HWND arg = nullptr) : id(arg) {}
-    HWND id;
-};
-
-/* struct RK_EXPORT RkNativeWindowInfo { */
-/*         RkNativeWindowInfo(HWND arg = nullptr) : window(arg) {} */
-/*         HINSTANCE instance; */
-/*         std::string className; */
-/*         HWND window; */
-/* }; */
-
-extern std::string RK_NO_EXPORT rk_winApiClassName;
-extern HINSTANCE RK_NO_EXPORT rk_winApiInstance;
-
-RkNativeWindowInfo RK_EXPORT rk_from_native_win(HINSTANCE instance,
-                                                LPCSTR className,
-                                                HWND window);
-RkWindowId RK_EXPORT rk_id_from_win(HWND window);
-
-#define RK_WIN_MESSAGE_PAINT (WM_USER + 0x0001)
-
-#elif RK_OS_MAC
-// to be defined
-#else // X11
 #include <X11/Xlib.h>
 
 struct RK_EXPORT RkWindowId {
         Window id;
 };
 
+struct _DndClass;
+
 class RK_EXPORT RkNativeWindowInfo
 {
  public:
-        RkNativeWindowInfo() : display{nullptr}, screenNumber{0}, window{0} {}
+
+ RkNativeWindowInfo() :
+        display{nullptr}
+        , screenNumber{0}
+        , window{0}
+        , dndHandle{nullptr}
+        , scaleFactor{1}{}
         ~RkNativeWindowInfo() = default;
         Display* display;
         int screenNumber;
         Window window;
+        std::shared_ptr<_DndClass> dndHandle;
+        double scaleFactor;
 };
 
 RkNativeWindowInfo RK_EXPORT rk_from_native_x11(Display* display,
@@ -77,5 +58,4 @@ RkNativeWindowInfo RK_EXPORT rk_from_native_x11(Display* display,
                                                 Window window);
 RkWindowId RK_EXPORT rk_id_from_x11(Window window);
 
-#endif // X11
 #endif // RK_PLATFORM_H
